module PC.Defaults      exposing (..)

import Array            exposing (Array)

import PC.Types         exposing (..)
import PC.UActions      exposing (..)


initalModel : PC_Model
initalModel =
    { pc        = initialPC
    , uCodes    = initialUCodes
    }

initialPC : PC
initialPC =
    { ram               = initialRam
    , dataBus           = 0
    , addressBus        = 0
    , instructionReg    = 0
    , programmCounter   = 0
    , uCounter          = 0
    , accumulator       = 0
    }


initialRam : Array (Int, String)
initialRam = Array.fromList
    [ (100005, "LoadA #005")    -- 000  -- LoadA    #005
    , (300000, "IncA")          -- 001  -- IncA
    , (200005, "StoreA #005")   -- 002  -- StoreA   #005
    , (400000, "JMP #000")      -- 003  -- JMP      #000
    , (0,"")                    -- 004
    , (5,"val")                 -- 005
    , (0, "")                   -- 006
    , (0, "")                   -- 007
    , (0, "")                   -- 008
    , (0, "")                   -- 009
    , (0, "")                   -- 010
    ]



initialUCodes : Array UAction
initialUCodes = Array.fromList
    [ UA_ProgrammCounter2AddressBus -- 000
    , UA_Ram2DataBus -- 001
    , UA_DataBus2InstructionReg -- 002
    , UA_ProgrammCounterIncrement -- 003
    , UA_InstructionReg2UCounter -- 004
    , UA_Nothing -- 005
    , UA_Nothing
    , UA_Nothing
    , UA_Nothing
    , UA_Nothing -- 009

    -- 010 LOADA
    , UA_InstructionReg2AddressBus -- 010
    , UA_Ram2DataBus -- 011
    , UA_DataBus2Accumulator -- 012
    , UA_ResetUCounter -- 013
    , UA_Nothing -- 014
    , UA_Nothing
    , UA_Nothing
    , UA_Nothing
    , UA_Nothing
    , UA_Nothing -- 019

    -- 020 STOA
    , UA_Accumulator2DataBus -- 020
    , UA_InstructionReg2AddressBus -- 021
    , UA_DataBus2Ram -- 022
    , UA_ResetUCounter -- 023
    , UA_Nothing --024
    , UA_Nothing
    , UA_Nothing
    , UA_Nothing
    , UA_Nothing
    , UA_Nothing -- 029

    -- 030 INCA
    , UA_AccumulatorIncrement -- 030
    , UA_ResetUCounter -- 031
    , UA_Nothing -- 032
    , UA_Nothing
    , UA_Nothing
    , UA_Nothing
    , UA_Nothing
    , UA_Nothing
    , UA_Nothing
    , UA_Nothing -- 039

    -- 040 JMP
    , UA_InstructionReg2ProgrammCounter -- 040
    , UA_ResetUCounter -- 041
    , UA_Nothing -- 042
    , UA_Nothing
    , UA_Nothing
    , UA_Nothing
    , UA_Nothing
    , UA_Nothing
    , UA_Nothing
    , UA_Nothing -- 049
    ]



